@@ -103,8 +103,7 @@ class TextPreprocessor:
                 (;-?\)+ | [-=][)(]+ | -_- | ^-^)          # 8
                 (\.|\s|$)                                 # 9
             )|(?:
-                ([\U00010000-\U0010ffff])                 # 10
-                #([\U0001f1e0-\U0001f6ff])                 # 10
+                ([\u2660-\u26ff\U00010000-\U0010ffff])    # 10
             )|(?:
                 (^|[^)(:;=-])                             # 11
                 (\)\)+ | \(\(+)                           # 12
